@@ -39,6 +39,17 @@ class TaskResult:
             trace = entity['StackTrace']
         return TaskResult(result, error, trace)
 
+    def to_json(self):
+        json_response = {"Completed": False}
+        if self.result:
+            json_response['Result'] = json.loads(self.result)
+            json_response['Completed'] = True
+        if self.error_message:
+            json_response['Error'] = self.error_message
+            json_response['StackTrace'] = self.stack_trace
+            json_response['Completed'] = True
+        return json_response
+
 
 def singleton(class_):
     instances = {}
